@@ -3,10 +3,13 @@
 # Distributed under the terms of the GNU General Public License (GPL).
 
 #version info for RuSocSci
-__version__='0.5'
+__version__='0.6'
 __license__='GNU GPLv3 (or more recent equivalent)'
 __author__='Wilbert van Ham'
 __author_email__='W.vanHam@socsci.ru.nl'
 __maintainer_email__='W.vanHam@socsci.ru.nl'
-__url__='http://www.socsci.ru.nl/~wilberth/psychopy'
+__url__='http://www.socsci.ru.nl/~wilberth/python/hardware.html'
 __build_platform__='n/a'
+
+
+
